summary refs log tree commit diff
path: root/pkgs
diff options
context:
space:
mode:
authorEelco Dolstra <eelco.dolstra@logicblox.com>2012-09-21 13:28:14 -0400
committerEelco Dolstra <eelco.dolstra@logicblox.com>2012-09-21 13:30:00 -0400
commit7057acb3226980e8556b9c69a25acee60af74442 (patch)
tree7272a38617351f33738e60dd2ca52431c38fc93b /pkgs
parent50aac3247a28e18113d021c4bb9d22e4a75886f9 (diff)
downloadnixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar.gz
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar.bz2
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar.lz
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar.xz
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.tar.zst
nixpkgs-7057acb3226980e8556b9c69a25acee60af74442.zip
systemd: Update to 190
Diffstat (limited to 'pkgs')
-rw-r--r--pkgs/os-specific/linux/systemd/default.nix10
-rw-r--r--pkgs/os-specific/linux/systemd/fail-after-reaching-respawn-limit.patch12
-rw-r--r--pkgs/os-specific/linux/systemd/name_to_handle_at.patch21
3 files changed, 26 insertions, 17 deletions
diff --git a/pkgs/os-specific/linux/systemd/fail-after-reaching-respawn-limit.patch b/pkgs/os-specific/linux/systemd/fail-after-reaching-respawn-limit.patch
deleted file mode 100644
index 7271b5578d5..00000000000
--- a/pkgs/os-specific/linux/systemd/fail-after-reaching-respawn-limit.patch
+++ /dev/null
@@ -1,12 +0,0 @@
-diff --git a/src/core/service.c b/src/core/service.c
-index 1c127bd..eafdbe5 100644
---- a/src/core/service.c
-+++ b/src/core/service.c
-@@ -2487,6 +2487,7 @@ static int service_start(Unit *u) {
-         r = service_start_limit_test(s);
-         if (r < 0) {
-                 service_notify_sockets_dead(s, true);
-+                service_set_state(s, SERVICE_FAILED);
-                 return r;
-         }
- 
diff --git a/pkgs/os-specific/linux/systemd/name_to_handle_at.patch b/pkgs/os-specific/linux/systemd/name_to_handle_at.patch
new file mode 100644
index 00000000000..99a7cc95723
--- /dev/null
+++ b/pkgs/os-specific/linux/systemd/name_to_handle_at.patch
@@ -0,0 +1,21 @@
+diff --git a/src/shared/missing.h b/src/shared/missing.h
+index c5bb71a..14abe4e 100644
+--- a/src/shared/missing.h
++++ b/src/shared/missing.h
+@@ -209,12 +209,12 @@ static inline pid_t gettid(void) {
+ #endif
+ 
+ #ifdef __x86_64__
+-#  ifndef __NR_name_to_handle
+-#    define __NR_name_to_handle 303
++#  ifndef __NR_name_to_handle_at
++#    define __NR_name_to_handle_at 303
+ #  endif
+ #else
+-#  ifndef __NR_name_to_handle
+-#    define __NR_name_to_handle 341
++#  ifndef __NR_name_to_handle_at
++#    define __NR_name_to_handle_at 341
+ #  endif
+ #endif
+
diff --git a/pkgs/os-specific/linux/systemd/default.nix b/pkgs/os-specific/linux/systemd/default.nix
index 796aa9c32f8..99b50ab1b33 100644
--- a/pkgs/os-specific/linux/systemd/default.nix
+++ b/pkgs/os-specific/linux/systemd/default.nix
@@ -1,23 +1,23 @@
 { stdenv, fetchurl, pkgconfig, intltool, gperf, libcap, dbus, kmod
 , xz, pam, acl, cryptsetup, libuuid, m4, utillinux, usbutils, pciutils
-, glib, kbd
+, glib, kbd, libxslt
 }:
 
 assert stdenv.gcc.libc or null != null;
 
 stdenv.mkDerivation rec {
-  name = "systemd-188";
+  name = "systemd-190";
 
   src = fetchurl {
     url = "http://www.freedesktop.org/software/systemd/${name}.tar.xz";
-    sha256 = "0nr1cg1mizbwcafjcqw3c30mx6xdv596jpbgjlxr6myvc5hfsfg8";
+    sha256 = "1p3pf8gvx43g62l9x85l8ym12wc373cmaysi41sahjndp2agicig";
   };
 
-  patches = [ ./fail-after-reaching-respawn-limit.patch ];
+  patches = [ ./name_to_handle_at.patch ];
 
   buildInputs =
     [ pkgconfig intltool gperf libcap dbus kmod xz pam acl
       /* cryptsetup */ libuuid m4 usbutils pciutils glib
     ];
 
   configureFlags =
@@ -1,23 +1,23 @@
   buildInputs =
     [ pkgconfig intltool gperf libcap dbus kmod xz pam acl
-      /* cryptsetup */ libuuid m4 usbutils pciutils glib
+      /* cryptsetup */ libuuid m4 usbutils pciutils glib libxslt
     ];
 